<?php
namespace Teknisa\FIS\Modules\Acessorias\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Fis11000CompraLegalBaFactory
{
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * Executa a procedure para a exportação de Compra LEGAL - BA [COMPRA_LEGAL_BA]
     */
    public function callCompraLegalBaProcedure($params) {
        $procedure = new StoredProcedure($this->connection, 'COMPRA_LEGAL_BA');
        
        $procedure->addParam(new Param('P_NRLISTA', Param::PARAM_INPUT, $params["NRLISTA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDIMPOSTO', Param::PARAM_INPUT, $params["CDIMPOSTO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINICIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFINAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQARQMAG', Param::PARAM_INPUT, $params["NRSEQARQMAG"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_LIVROMAG', Param::PARAM_INPUT, null, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDINSCESTA', Param::PARAM_INPUT, $params["CDINSCESTA"], Param::PARAM_TYPE_STR));
     
        $procedure->execute();
    }
    
    /*
     * Função para excluir os dados gerados na procedure de Compra LEGAL - BA.
     */
    public function deleteCompraLegalBaData($params) {
        // Query a ser executada.
        $sql = "DELETE FROM ARQMAGNETICO WHERE NRSEQARQMAG = :NRSEQARQMAG AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);
    }
    
    /*
     * Função para retornar a sigla do estado relacionado a uma inscrição estadual.
     */
    public function getEstadoInscricaoEstadual($params) {
        // Query a ser executada.
        $sql = "SELECT SGESTADO FROM INSCRESTAD WHERE CDEMPRESA = :CDEMPRESA AND CDINSCESTA = :CDINSCESTA AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetch(\PDO::FETCH_ASSOC);
        
    }

    /*
     * Função para retornar os dados gerados na procedure de Compra LEGAL - BA.
     */
    public function getCompraLegalBaData($params) {
        
        // Query a ser executada.
        $sql = "SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG 
                FROM ARQMAGNETICO 
                WHERE NRORG = :NRORG 
                    AND NRSEQARQMAG = :NRSEQARQMAG 
                ORDER BY NRORDREGARQ, SUBSTR(DSREGARQMAG,1,17)";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetchAll();
    }    
    
    public function findAgendamento() {
        // Query a ser executada.
        $sql = "SELECT 
                    A.NRORG,
                    A.NRAGENDAMENTO,
                    A.CDTELA,
                    A.CDEMPRESA,
                    E.NMEMPRESA,
                    A.CDINSCESTA,
                    A.DTAGENDAMENTO,
                    A.DTINICIAL,
                    A.DTFINAL,
                    A.CDCAMPO1 AS CDIMPOSTONFE,
                    DECODE(A.IDPERIAGEN, '0', A.DTINICIAL,
                                   '1', TO_CHAR(SYSDATE, 'DD/MM/YYYY'),
                                   '2', TO_CHAR(ADD_MONTHS(SYSDATE,(-1)), 'DD/MM/YYYY')) AS DTREFINI,
                    I.SGIMPOSTONFE,
                    A.IDPERIAGEN,
                    A.IDSTATUS
                    FROM AGENDOBRIGACESS A,
                    EMPRESA E,
                    IMPOSTONFE I
                    WHERE CDTELA  = 'FIS11000'
                    AND A.CDEMPRESA = E.CDEMPRESA
                    AND A.CDCAMPO1 = I.CDIMPOSTONFE";
                    

        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute();
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function insertAgendamento($row) {
        $sql = "INSERT INTO AGENDOBRIGACESS
            ( 
                NRORG,
                NRAGENDAMENTO,
                CDTELA,
            	CDEMPRESA,
                CDINSCESTA,
            	DTAGENDAMENTO,
            	DTINICIAL,
            	DTFINAL,
                IDPERIAGEN,
            	
            	CDCAMPO1,
                DTCAMPO1   ) 
             VALUES (
                :NRORG,
                :NRAGENDAMENTO,
                :CDTELA,
                :CDEMPRESA,
                :CDINSCESTA,
                :DTAGENDAMENTO,
                :DTINICIAL,
                :DTFINAL,
                :IDPERIAGEN,
                :CDCAMPO1,
                :DTCAMPO1 )";
                
        $params = array(
            "NRORG"         => $row["NRORG"],
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            "IDPERIAGEN"=> $row["IDPERIAGEN"],
            "CDCAMPO1"  => $row["CDIMPOSTONFE"],
            "DTCAMPO1"  => $row["DTREFINI"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateAgendamento($row) {
        $sql = "UPDATE AGENDOBRIGACESS
                    SET CDEMPRESA = :CDEMPRESA,
                        CDINSCESTA = :CDINSCESTA,
                    	DTAGENDAMENTO = :DTAGENDAMENTO,
                    	DTINICIAL = :DTINICIAL,
                    	DTFINAL = :DTFINAL,
                    	IDPERIAGEN = :IDPERIAGEN,
                    	CDCAMPO1 = :CDCAMPO1,
                        DTCAMPO1 = :DTCAMPO1
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND CDTELA = :CDTELA";
                    
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            "IDPERIAGEN"=> $row["IDPERIAGEN"],
            "CDCAMPO1"  => $row["CDIMPOSTONFE"],
            "DTCAMPO1"  => $row["DTREFINI"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateAgendamentoIdStatus($row, $idstatus) {
        $sql = "UPDATE AGENDOBRIGACESS
                    SET IDSTATUS = :IDSTATUS
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND CDTELA = :CDTELA";
                    
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "IDSTATUS"      => $idstatus
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getInscEsta($row) {
        // Query a ser executada.
        $sql = "SELECT CDINSCESTA FROM INSCRESTAD WHERE CDEMPRESA = :CDEMPRESA";

        $params = array(
            'CDEMPRESA' => $row['CDEMPRESA']
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function getAgendamentoInsert($row) {
        // Query a ser executada.
        $sql = "SELECT * FROM AGENDOBRIGACESS 
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";

        $params = array(
            "NRAGENDAMENTO"=>$row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function getConfiguraSMTP($row)  {
        // Query a ser executada.
        $sql = "SELECT * FROM CONFIGURASMTP
                    WHERE NRORG = :NRORG";
        
        $params = array(
            "NRORG"=> $row["NRORG"]
        );
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getContatos($row)  {
        // Query a ser executada.
        $sql = "SELECT * FROM CONTATOAPURAC
                    WHERE NRORG = :NRORG
                    AND CDEMPRESA = :CDEMPRESA
                    AND IDEXPORTAUTO = 'S'";
        
        $params = array(
            "NRORG"     => $row["NRORG"],
            "CDEMPRESA" => $row["CDEMPRESA"]
        );
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getAgendamentoArquivo($row) {
        $sql = "SELECT * FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function deleteAgendamentoArquivo($row) {
        $sql = "DELETE FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
    }
  
    public function deleteAgendamento($row) {
        // Query a ser executada.
        $sql = "DELETE FROM AGENDOBRIGACESS 
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";

        $params = array(
            "NRAGENDAMENTO"=>$row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
    }
    
    public function findAgendamentoExec($row) {
        // Query a ser executada.
        $sql = "SELECT 
                    TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI') AS DTATUAL,
                    TO_CHAR(ADD_MONTHS(SYSDATE,(-1)), 'DD/MM/YYYY HH24:MI') AS LAST_MONTH,
                    A.NRAGENDAMENTO,
                    A.CDTELA,
                    A.CDEMPRESA,
                    A.CDINSCESTA,
                    A.DTAGENDAMENTO,
                    A.DTINICIAL,
                    A.DTFINAL,
                    A.CDCAMPO1 AS CDIMPOSTO,
                    A.DTCAMPO1 AS DTREFINI,
                    A.IDPERIAGEN,
                    A.IDSTATUS
                    FROM AGENDOBRIGACESS A
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO"=> $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function findNotasFiscaisExec($row) {
        // Query a ser executada.
        $sql = "SELECT
                     NF.NRORG,
                     NF.IDENTRSAIDOP,
                     NF.CDCLIENTE,
                     NF.IDSTATUS,
                     NF.CDFILIAL,
                     NF.NRLANCTONF,
                     NF.DTEMISSAO,
                     NF.NRNOTAFISC,
                     NF.VRNOTAFISC,
                     NF.CDTIPOOPER,
                     NF.CDINSCESTA,
                     NF.CDINSCMUNI,
                     NF.CDSERIE,
                     NF.CLIENTE,
                     NVL(NF.IDNFCOMPRALEG,'N') AS IDNFCOMPRALEG
                 FROM
                     (
                         SELECT
                             N.NRORG,
                             N.IDENTRSAIDOP,
                             N.CDCLIENTE,
                             'U' AS IDSTATUS,
                             N.CDFILIAL,
                             N.NRLANCTONF,
                             N.DTEMISSAO,
                             N.NRNOTAFISC,
                             ROUND(N.VRNOTAFISC,2) AS VRNOTAFISC,
                             N.CDTIPOOPER,
                             N.CDINSCESTA,
                             N.CDINSCMUNI,
                             N.CDSERIE,
                             N.NRINSJURNF
                             || ' - '
                             || C.NMRAZSOCCLIE AS CLIENTE,
                             N.IDNFCOMPRALEG
                         FROM
                             NOTAFISCAL N,
                             CLIENTE C
                         WHERE
                             N.CDEMPRESA =:P_CDEMPRESA
                             AND N.IDENTRSAIDOP = 'S'
                             AND N.IDORIGDESTNF = 'C'
                             AND N.IDNFCOMPRALEG = 'N'
                             AND N.DTEMISSAO BETWEEN :P_DTINICIAL AND :P_DTFINAL
                             AND N.IDSTATUS IN (
                                 'A',
                                 'E'
                             )
                             AND N.CDCLIENTE = C.CDCLIENTE
                             AND N.VRNOTAFISC >= 0
                             AND ( NVL(N.IDSISTEMA,'DFS') <> 'REC'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'PAG'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'CMP'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'SUP'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'FIS' )
                         UNION ALL
                         SELECT
                             N.NRORG,
                             N.IDENTRSAIDOP,
                             N.CDFORNECED   AS CDCLIENTE,
                             'U' AS IDSTATUS,
                             N.CDFILIAL,
                             N.NRLANCTONF,
                             N.DTEMISSAO,
                             N.NRNOTAFISC,
                             ROUND(VRNOTAFISC,2) AS VRNOTAFISC,
                             CDTIPOOPER,
                             CDINSCESTA,
                             CDINSCMUNI,
                             CDSERIE,
                             N.NRINSJURNF
                             || ' - '
                             || F.NMRAZSOCFORN AS CLIENTE,
                             N.IDNFCOMPRALEG
                         FROM
                             NOTAFISCAL N,
                             FORNECEDOR F
                         WHERE
                             N.CDEMPRESA =:P_CDEMPRESA
                             AND N.IDENTRSAIDOP = 'S'
                             AND N.IDORIGDESTNF = 'F'
                             AND N.IDNFCOMPRALEG = 'N'
                             AND N.DTEMISSAO BETWEEN :P_DTINICIAL AND :P_DTFINAL
                             AND N.IDSTATUS IN (
                                 'A',
                                 'E'
                             )
                             AND N.CDFORNECED = F.CDFORNECED
                             AND N.VRNOTAFISC >= 0
                             AND ( NVL(N.IDSISTEMA,'DFS') <> 'REC'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'PAG'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'CMP'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'SUP'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'FIS' )
                         UNION ALL /* notas de entrada */
                         SELECT
                             N.NRORG,
                             N.IDENTRSAIDOP,
                             N.CDFORNECED,
                             'U' AS IDSTATUS,
                             N.CDFILIAL,
                             N.NRLANCTONF,
                             N.DTEMISSAO,
                             N.NRNOTAFISC,
                             ROUND(VRNOTAFISC,2) AS VRNOTAFISC,
                             N.CDTIPOOPER,
                             CDINSCESTA,
                             CDINSCMUNI,
                             N.CDSERIEENTR   AS CDSERIE,
                             N.NRINSJURNF
                             || ' - '
                             || F.NMRAZSOCFORN AS CLIENTE,
                             N.IDNFCOMPRALEG
                         FROM
                             NOTAFISCAL N,
                             FORNECEDOR F,
                             TIPOOPERAC T
                         WHERE
                             N.CDEMPRESA =:P_CDEMPRESA
                             AND N.IDENTRSAIDOP = 'E'
                             AND N.IDORIGDESTNF = 'F'
                             AND N.IDNFCOMPRALEG = 'N'
                             AND N.DTEMISSAO BETWEEN :P_DTINICIAL AND :P_DTFINAL
                             AND N.IDSTATUS IN (
                                 'A',
                                 'E'
                             )
                             AND T.IDUTILEMISNF = 'S'
                             AND N.CDTIPOOPER = T.CDTIPOOPER
                             AND N.CDFORNECED = F.CDFORNECED
                             AND N.VRNOTAFISC >= 0
                             AND ( NVL(N.IDSISTEMA,'DFS') <> 'REC'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'PAG'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'CMP'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'SUP'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'FIS' )
                         UNION ALL
                         SELECT
                             N.NRORG,
                             N.IDENTRSAIDOP,
                             N.CDCLIENTE,
                             'U' AS IDSTATUS,
                             N.CDFILIAL,
                             N.NRLANCTONF,
                             N.DTEMISSAO,
                             N.NRNOTAFISC,
                             ROUND(VRNOTAFISC,2) AS VRNOTAFISC,
                             N.CDTIPOOPER,
                             N.CDINSCESTA,
                             N.CDINSCMUNI,
                             N.CDSERIEENTR   AS CDSERIE,
                             N.NRINSJURNF
                             || ' - '
                             || C.NMRAZSOCCLIE AS CLIENTE,
                             N.IDNFCOMPRALEG
                         FROM
                             NOTAFISCAL N,
                             CLIENTE C,
                             TIPOOPERAC T
                         WHERE
                             N.CDEMPRESA =:P_CDEMPRESA
                             AND N.IDENTRSAIDOP = 'E'
                             AND N.IDORIGDESTNF = 'C'
                             AND N.IDNFCOMPRALEG = 'N'
                             AND N.DTEMISSAO BETWEEN :P_DTINICIAL AND :P_DTFINAL
                             AND N.IDSTATUS IN (
                                 'A',
                                 'E'
                             )
                             AND T.IDUTILEMISNF = 'S'
                             AND N.CDTIPOOPER = T.CDTIPOOPER
                             AND N.CDCLIENTE = C.CDCLIENTE
                             AND N.VRNOTAFISC >= 0
                             AND ( NVL(N.IDSISTEMA,'DFS') <> 'REC'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'PAG'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'CMP'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'SUP'
                                   AND NVL(N.IDSISTEMA,'DFS') <> 'FIS' )
                     ) NF
                 ORDER BY
                     NF.NRNOTAFISC,
                     NF.DTEMISSAO";
        
        $params = array(
            "P_CDEMPRESA"   => $row["CDEMPRESA"],
            "P_DTINICIAL"   => substr($row["DTINICIAL"], 0, 10),
            "P_DTFINAL"     => substr($row["DTFINAL"], 0, 10)
        );
        var_dump($params);
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getNmEmpresa($row) {
        // Query a ser executada.
        $sql = "SELECT NMEMPRESA FROM EMPRESA
                    WHERE CDEMPRESA = :CDEMPRESA
                    AND NRORG = :NRORG";
        
        $params = array(
            "CDEMPRESA" => $row["CDEMPRESA"],
            "NRORG"     => $row["NRORG"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetch();
    }
    
    public function verAgendamentoArquivo($row) {
        $sql = "SELECT * FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                AND NMARQUIVO = :NMARQUIVO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "NMARQUIVO"     => $row["NMARQUIVO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function insertAgendamentoArquivo($row) {
        $sql = "INSERT INTO ARQUIOBRIGACESS
            ( 
                NRORG,
                NRARQUIVO,
                NRAGENDAMENTO,
                CDTELA,
                CDEMPRESA,
                CDINSCESTA,
                DTAGENDAMENTO,
                DTEXECAGEND,
                NMARQUIVO,
                NMPATHARQ
            )
             VALUES (
                :NRORG,
                :NRARQUIVO,
                :NRAGENDAMENTO,
                :CDTELA,
                :CDEMPRESA,
                :CDINSCESTA,
                :DTAGENDAMENTO,
                :DTEXECAGEND,
                :NMARQUIVO,
                :NMPATHARQ  )";
        
        $params = array(
            "NRORG"         => $row["NRORG"],
            "NRARQUIVO"     => $row["NRARQUIVO"],
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            "DTEXECAGEND"   => $row["DTEXECAGEND"],
            "NMARQUIVO"     => $row["NMARQUIVO"],
            "NMPATHARQ"     => $row["NMPATHARQ"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function saveListaCompraLegalBa($row) {
        $sql = "INSERT INTO LISTA
            ( 
                NRORG,
                NRLISTA,
                CDLISTA
            )
             VALUES (
                :NRORG,
                :NRLISTA,
                :CDLISTA  )";
        
        $params = array(
            "NRORG"     => $row["NRORG"],
            "NRLISTA"   => $row["NRLISTA"],
            "CDLISTA"   => $row["CDLISTA"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
 
    public function deleteListaCompraLegalBa($row) {
        // Query a ser executada.
        $sql = "DELETE FROM LISTA WHERE NRLISTA = :NRLISTA";
        
        $params = array(
            "NRLISTA"   => $row["NRLISTA"]
        ) ;
            
        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);
    }
   
}