<?php
namespace Teknisa\FIS\Modules\Acessorias\Services;

use Teknisa\FIS\Modules\Acessorias\Factories\Fis07600ValidaPrFactory;
use Teknisa\FIS\Modules\Acessorias\Services\Fis91000ObrigacoesAcessoriasService;
use Teknisa\FIS\Modules\Acessorias\Services\Agendamento;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\NewCode;
use \Teknisa\Libs\Util\Libraries\PHPMailer;

class Fis07600ValidaPrService
{
    protected $environment;
    protected $validaPrFactory;
    protected $obrigacoesService;
    
    public $mensagemBody = '';
    public $mensagemBodySucess = '';
    public $mensagemError = '';
    public $mensagemErrorBody = '';
    public $geraArquivo = '';

    public function __construct(Environment $environment, Fis07600ValidaPrFactory $validaPrFactory, Fis91000ObrigacoesAcessoriasService $obrigacoesService,
                                    NewCode $newCode, Agendamento $agendamento )
    {
        $this->environment          = $environment;
        $this->validaPrFactory      = $validaPrFactory;
        $this->obrigacoesService    = $obrigacoesService;
        $this->newCode              = $newCode;
        $this->agendamento          = $agendamento;
    }

    /**
     * Função para criar o arquivo da exportação ValidaPR
     */
    private function createFileValidaPr($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $params = [
            'NRORG' => $row['NRORG'],
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];
        $validaPrData = $this->validaPrFactory->getValidaPrData($params);

        if(isset($row['NRAGENDAMENTO']) && empty($validaPrData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $validaPrData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }
    
        /**
     * Função para criar o arquivo da exportação adrc
     */
    private function createFileAdrc($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $nrorg = $this->environment->getNrorg();
        $params = [
            'NRORG' => $nrorg,
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];
        $validaPrData = $this->validaPrFactory->getValidaPrData($params);

        if(isset($row['NRAGENDAMENTO']) && empty($validaPrData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $validaPrData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }

    /**
     * Função para a exportação ValidaPR
     */
    public function exportarValidaPr($row) {
        // Valida os parâmetros associados.
        $this->validateValidaPr($row);
        
        if(isset($row['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['NRORG']);
        //Gera o campo DTPOSICAO
        $data = date('Y-m-d', strtotime(str_replace('/', '-', $row['DTFINAL'])));
        $row['DTPOSICAO']   = date('d/m/Y', strtotime($data.'+ 1days'));
        // Monta o array com os parametros para chamar a procedure
        $params = [
            'CDREGISTRO'    => $row['CDREGISTRO'],
            'CDIMPOSTO'     => '00',
            'CDEMPRESA'     => $row['CDEMPRESA'],
            'CDINSCESTA'    => $row['CDINSCESTA'],
            'DTINICIAL'     => $row['DTINICIAL'],
            'DTFINAL'       => $row['DTFINAL'],
            'DTPOSICAO'     => $row['DTPOSICAO'],
            'CDPAIS'        => $row['CDPAIS'],
            'SGESTADO'      => $row['SGESTADO'],
            'VERSAO'        => $row['CDCONVENIO'],
            'CDFINALIDADE'  => $row['CDFINALIDADE'],
            "NRSEQARQMAG"   => $row["NRSEQARQMAG"],
        ];
        
        // Chama a procedure de exportação
        $this->validaPrFactory->callValidaPrProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['NRORG'],
                'NRSEQARQMAG' => $row['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileValidaPr($row);

            // Exclui os dados temporários da exportação no banco de dados
            $this->validaPrFactory->deleteValidaPrData($params);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            // Exclui os dados temporários da exportaçao no banco de dados
            $this->validaPrFactory->deleteValidaPrData($params);
            throw $e;
        }

    }

    /**
     * Função para a exportação ValidaPR
     */
    public function exportarADRC($row) {
        
        $nrorg = $this->environment->getNrorg();
       // var_dump($row);die;
        $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL']   = $datas['DTINICIAL'];
            $row['DTFINAL']     = $datas['DTFINAL'];
    
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($nrorg);
        // Monta o array com os parametros para chamar a procedure
        $params = [
            'CDEMPRESA'     => $row['CDEMPRESA'],
            'CDINSCESTA'    => $row['CDINSCESTA'],
            'VERSAO'        => $row['VERSAO'],
            'DTINICIAL'    => $row['DTINICIAL'],
            'DTFINAL'  => $row['DTFINAL'],
            'FINALIDADE'  => $row['FINALIDADE'],
            'NRREGESPECIAL'  => $row['NRREGESPECIAL'],
            'IDCENTRDISTR'  => $row['IDCENTRDISTR'],
            'CDEMPRESADISTR'  => $row['CDEMPRESADISTR'],
            'CDINSCESTADISTR'  => $row['CDINSCESTADISTR'],
            "NRSEQARQMAG"   => $row["NRSEQARQMAG"],
        ];
        
        // Chama a procedure de exportação
        $this->validaPrFactory->callAdrcProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $nrorg,
                'NRSEQARQMAG' => $row['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileAdrc($row);

            // Exclui os dados temporários da exportação no banco de dados
            $this->validaPrFactory->deleteAdrcData($params);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            // Exclui os dados temporários da exportaçao no banco de dados
            $this->validaPrFactory->deleteAdrcData($params);
            throw $e;
        }

    }

 
    /**
     * Função para validação dos dados informados para o ValidaPR
     */
    private function validateValidaPr($row) {
        if (isset($row['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
            
            // Verfifica se o campo 'Registro' possui algum vlr informado
            if(empty($row['CDREGISTRO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Registro deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Registro deve ser informado');
            }
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
            // Verifica se o campo 'Identificação do Convênio' possui algum vlr informado
            if(empty($row['CDCONVENIO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Identificação do Convênio deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Identificação do Convênio deve ser informado');
            }
            // Verifica se o campo 'Finalidade do Arquivo' possui algum vlr informado
            if(empty($row['CDFINALIDADE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Finalidade do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Finalidade do Arquivo deve ser informado');
            }
            
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            //$nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL']   = $datas['DTINICIAL'];
            $row['DTFINAL']     = $datas['DTFINAL'];
            
            //$data = date('Y-m-d', strtotime(str_replace('/', '-', $row['DTFINAL'])));
            //$row['DTPOSICAO']   = date('d/m/Y', strtotime($data.'+ 1days'));
            //$row['NRORG'] = $nrorg;
    
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
    
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                $this->mensagemError = $this->mensagemError.'<br />'.'Todos os mapas devem estar bloquados para a geração do arquivo.';
                $this->geraArquivo = false;
                //throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
        else {
            // Verfifica se o campo 'Registro' possui algum vlr informado
            if(empty($row['CDREGISTRO'])){
                throw new \Exception('Registro deve ser informado');
            }
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                throw new \Exception('Inscrição Estadual deve ser informado');
            }
            // Verifica se o campo 'Identificação do Convênio' possui algum vlr informado
            if(empty($row['CDCONVENIO'])){
                throw new \Exception('Identificação do Convênio deve ser informado');
            }
            // Verifica se o campo 'Finalidade do Arquivo' possui algum vlr informado
            if(empty($row['CDFINALIDADE'])){
                throw new \Exception('Finalidade do Arquivo deve ser informado');
            }
            
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL']   = $datas['DTINICIAL'];
            $row['DTFINAL']     = $datas['DTFINAL'];
            $row['NRORG']       = $nrorg;
            
            //$data = date('Y-m-d', strtotime(str_replace('/', '-', $row['DTFINAL'])));
            //$row['DTPOSICAO']   = date('d/m/Y', strtotime($data.'+ 1days'));
        
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
        
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
    }
    
    
    public function findAgendamento() {
        // Busca os parâmetros conforme empresa e nrorg.
        $agendamento = $this->validaPrFactory->findAgendamento();

        return $agendamento;
    }
    
    public function saveAgendamento($row) {
        try {
            $row['CDTELA'] = 'FIS07600';
            
            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtinicial = $dtinicial->format("d/m/Y");
            $dtfinal = $dtfinal->format("d/m/Y");
    
            $row["DTINICIAL"] = $dtinicial;
            $row["DTFINAL"] = $dtfinal;
            
            //var_dump($row);
            //throw new \Exception('ioioioioioi');
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $row["NRAGENDAMENTO"] = $this->newCode->getCodeByTableName('NRAGENDAMENTO', $row["NRORG"], 1, 10);
            }
            
            if($row['CDINSCESTA'] == 'T'){
                $arrayInscEsta = $this->validaPrFactory->getInscEsta($row);
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value['CDINSCESTA'].'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } else if(is_array($row['CDINSCESTA']) == true){
                $arrayInscEsta = $row['CDINSCESTA'];
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value.'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } 
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $this->validaPrFactory->insertAgendamento($row);
            } else {
                $this->validaPrFactory->updateAgendamento($row);
                
                 $arquivos = $this->validaPrFactory->getAgendamentoArquivo($row);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->validaPrFactory->deleteAgendamentoArquivo($arquivo);
                }
                
                $idstatus = 'P';
                $this->validaPrFactory->updateAgendamentoIdStatus($row, $idstatus);
                
            }
            
            $agendamento = $this->validaPrFactory->getAgendamentoInsert($row);
            
            if($agendamento){
                
                $agendamento['NRORG'] = $row['NRORG'];
                $getConfigSMTP = $this->validaPrFactory->getConfiguraSMTP($agendamento)[0];
                if(isset($row['__is_new']) && $row['__is_new'] == true){
                    $nomeJob = $row['CDTELA'].'_'.$row['NRAGENDAMENTO'];
                } else {
                    $nomeJob = $row['CDTELA'].'_'.str_pad($row['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                }
                $dataContabAuto = $row['DTAGENDAMENTO'];
                $sequencialJob = $row['NRAGENDAMENTO'];
                $nrorg = $row['NRORG'];
                $descricao = $row['CDTELA'].' - ValidaPR'.'. Exportação das declarações Acessórias de forma automática na data de '.$row['DTAGENDAMENTO'];
                //Conferir caminho do diretorio do xampp
                $arqCallService = $getConfigSMTP['CALLSERVPATH'];//'C:\Teknisa\CallService.php';
                //$dirphp = str_replace('/','\',$DIRPHP);
                $dirphp = $getConfigSMTP['DIRPHP'];//'C:/xampp/php';
                $jenkinsPath = $getConfigSMTP['JENKINSPATH'];//'http://192.168.120.132:8080/';
                $execPath = '/execAgendamentoValidaPr';
                $periodicidade = $row['IDPERIAGEN'];
                $jenkinsCreateItem = $getConfigSMTP['JENKCREATITEM'];
                $this->agendamento->criaJob($nomeJob, $dataContabAuto, $sequencialJob, $nrorg, $descricao, $arqCallService, $dirphp, $jenkinsPath, $execPath, $periodicidade, $jenkinsCreateItem);
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
    }
    
    public function execAgendamento($row){
        try{
            $agendamento = $this->validaPrFactory->findAgendamentoExec($row)[0];
            
            $findParamDeclAcess = $this->validaPrFactory->findParamDeclAcess($agendamento);
            
            $agendamento['CDCONVENIO'] = isset($findParamDeclAcess['CDCONVENIO']) ? $findParamDeclAcess['CDCONVENIO'] : null;
            $agendamento['CDFINALIDADE']   = isset($findParamDeclAcess['CDFINALIDADE']) ? $findParamDeclAcess['CDFINALIDADE'] : null;
            $agendamento['CDREGISTRO']  = isset($findParamDeclAcess['CDREGISTRO']) ? $findParamDeclAcess['CDREGISTRO'] : null;
            
            if($agendamento){
                $this->mensagemBody = '';
                
                $agendamento["NRORG"] = $row['NRORG'];
                
                $agendamento["DTEXECAGEND"] = $agendamento["DTATUAL"];
                
                $agendamento["DTREFINI"] = explode(' ', $agendamento["DTREFINI"])[0];
                
                //Necessário Fazer a verificação
                
                $agendamento['CDINSCESTAARRAY'] = $agendamento['CDINSCESTA'];
                $arrayInscEsta = explode('_',$agendamento['CDINSCESTAARRAY']);
                
                $getConfigSMTP = $this->validaPrFactory->getConfiguraSMTP($agendamento)[0];
                $getContatos = $this->validaPrFactory->getContatos($agendamento);
                
                $mail = new PHPMailer;
                $mail->CharSet = 'UTF-8';
                $mail->isSMTP();                        // Set mailer to use SMTP
                $mail->isHTML();
                $mail->Host = $getConfigSMTP['SERVIDORSMTP'];       // Specify main and backup SMTP servers
                $mail->SMTPAuth = true;                 // Enable SMTP authentication
                $mail->Username = $getConfigSMTP['LOGINSMTP'];    // SMTP username
                $mail->Password = $getConfigSMTP['SENHASMTP'];    // SMTP password
                $mail->From = $getConfigSMTP['LOGINSMTP'];
                $mail->FromName = 'ERP Pebbian';
                $mail->Subject = 'ValidaPR de '.$agendamento['DTAGENDAMENTO'];
                // $mail->addAddress($cliente['DSEMAILCLIE']);
                // $mail->addAddress($vendedor['DSEMAILOPER']);
                
                foreach($getContatos as $contato){
                    $mail->addAddress($contato['EMAIL']);
                };
                
                $agendamento["NMEMPRESA"] = $this->validaPrFactory->getNmEmpresa($agendamento)["NMEMPRESA"];
                        
                $this->mensagemBody = 'Caro cliente, '.'<br />'.'<br />';
                $this->mensagemBodySucess = 'Arquivo de ValidaPR gerado com Sucesso!'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                $this->mensagemErrorBody = 'Erro ao gerar o arquivo de ValidaPR:'.'<br />'.'<br />'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                
                
                $contErro = 0;
                $contSucess = 0;
                
                foreach( $arrayInscEsta as $inscEsta ){
                    if(isset($inscEsta) && $inscEsta != ''){
                        
                       $this->geraArquivo = true;
                            
                        $dataName = str_replace('/', '', explode(' ', $agendamento["DTATUAL"])[0]);
                        $horaName = str_replace(':', '', explode(' ', $agendamento["DTATUAL"])[1]);
                        
                        if($agendamento['IDPERIAGEN'] == '0'){
                            $dtinicial = $agendamento["DTINICIAL"];
                            $dtfinal = $agendamento["DTFINAL"];
                        } 
                        else if($agendamento['IDPERIAGEN'] == '1'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        } 
                        else if($agendamento['IDPERIAGEN'] == '2'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        }
                
                        $agendamento["DTINICIAL"] = $dtinicial;
                        $agendamento["DTFINAL"] = $dtfinal;
                        
                        $agendamento['CDINSCESTA'] = $inscEsta;
                        $agendamento["NMARQUIVO"] = $agendamento['CDTELA'].$agendamento['NRAGENDAMENTO'].'_'.$inscEsta.'_'.$dataName.$horaName;
                          
                        $fileName = $this->exportarValidaPr($agendamento);
                        
                        if($this->mensagemError == ''){
                            $this->mensagemBodySucess = $this->mensagemBodySucess
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA'];
                            ++$contSucess;
                            
                        } else {
                            $this->mensagemErrorBody = $this->mensagemErrorBody
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA']
                            .$this->mensagemError.'<br />'.'<br />';
                            ++$contErro;
                        }
                        
                        if($fileName){
                            $file = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $fileName;
                            $agendamento["NMPATHARQ"] = $file ;
                            
                            $verifArq = $this->validaPrFactory->verAgendamentoArquivo($agendamento);
                            
                            if(empty($verifArq)){
                                $agendamento["NRARQUIVO"] = $this->newCode->getCodeByTableName('NRARQUIVO', $agendamento["NRORG"], 1, 10);
                                $this->validaPrFactory->insertAgendamentoArquivo($agendamento);
                            }
                        }
                
                    }
                }
                
                if(($contErro > 0) && ($contSucess > 0)){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'.'<br />'
                    .'---------------------------------------------------------------------'.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                } 
                else if($contErro > 0){
                    $mail->Body = $this->mensagemBody.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                else if($contSucess > 0){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                
                $idstatus = 'R';
                $this->validaPrFactory->updateAgendamentoIdStatus($agendamento, $idstatus);
                
            }
        
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteAgendamento($row){
        try {    
            
            $agendamento = $this->validaPrFactory->getAgendamentoInsert($row)[0];
            
            
            if($agendamento){
                $nomeJob = $agendamento['CDTELA'].'_'.str_pad($agendamento['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                $getConfigSMTP = $this->validaPrFactory->getConfiguraSMTP($agendamento)[0];
                
                $this->agendamento->apagaJob($nomeJob, null, $getConfigSMTP['JENKINSPATH'], $getConfigSMTP["CALLSERVPATH"]);
                
                $arquivos = $this->validaPrFactory->getAgendamentoArquivo($agendamento);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->validaPrFactory->deleteAgendamentoArquivo($arquivo);
                    $this->validaPrFactory->deleteAgendamento($arquivo);
                    
                } else {
                    $this->validaPrFactory->deleteAgendamento($agendamento);
                }
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
                
    }
 
    private function formataData($data) {
        if (!$data) {
            return null;
        }

        // Verifica se está com o formato de data-hora.
        if (strlen($data) == 19) {
            $data = DateUtil::truncateString($data);
        }
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }
    
    
    
    
    
    
    
    // ESSA PARTE É DESTINADA PARA AS FUNÇÕES DA FIS08300_GIAMTO
    
       /* Função para criar o arquivo da exportação GIA-TO
     */
    private function createFileGiamTo($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        
        $params = [
            'NRORG' => $row['current']['NRORG'],
            'NRSEQARQMAG' => $row['current']['NRSEQARQMAG'],
        ];
        $giamToData = $this->validaPrFactory->getGiamToData($params);
        //var_dump($row);die;
        if(isset(['current']['NRAGENDAMENTO']) && empty($giamToData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['current']['NMARQUIVO'], $giamToData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }

     /**
     * Função para a exportação GIA-TO
     */
    public function exportarGiamTO($row) {
        // Valida os parâmetros associados.
       ///var_dump($row);die;

        $this->validateGiamTo($row);
        
        if(isset($row['current']['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['current']['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['current']['NRORG']);
        // Monta o array com os parametros para chamar a procedure
       // var_dump($row['dataset']);die;
        $params = [
            'CDEMPRESA' =>$row['dataset'][0]['CDEMPRESA'],
            'CDINSCESTA' =>$row['dataset'][0]['CDINSCRICAO'],   
            'CDREPRESENT' =>$row['dataset'][0]['CDREPRES'],
            'IDRETIFIC' =>$row['dataset'][0]['IDRETIFIC'],
            'IDTPESTAB' =>$row['dataset'][0]['IDTPESTAB'],
            'IDTPESCRIT' =>$row['dataset'][0]['CDTPESCRITU'],
            'VRINICAIXA' =>$row['dataset'][0]['SALDOINICX'],
            'VRFIMCAIXA' =>$row['dataset'][0]['SALDOFINCX'],
            'IDUSAECF' =>$row['dataset'][0]['IDUSUARIOECF'],
            'VERSAO' =>$row['dataset'][0]['CDVERSAO'],
            'IDPORTTARE' =>$row['dataset'][0]['IDPORTTARE'],
            'NRTARE' =>$row['dataset'][0]['NRTARE'],
            'DTVENCTARE' =>$row['dataset'][0]['DTVALTARE'],
            'IDMUDDOMICI' =>$row['dataset'][0]['IDMUDAMUNI'],    
            'CDMUNIANT' =>$row['dataset'][0]['CDMUNIANT'],
            'DTINIMUNIANT' =>$row['dataset'][0]['DTINIMUNIANT'], 
            'DTFINMUNIANT' =>$row['dataset'][0]['DTFINMUNIANT'], 
            'DTINIMUNIATU' =>$row['dataset'][0]['DTINIMUNIATU'], 
            'DTFINMUNIATU' =>$row['dataset'][0]['DTINIMUNIATU'],
            'NRSEQARQMAG' => $row['current']["NRSEQARQMAG"],
            'LIVRO' => $row['current']["CDLIVROMAG"],
            'DTINICIO' => $row['current']['DTINICIO'],
            'DTFIM' => $row['current']['DTFIM'],

        ];
            
        // Chama a procedure de exportação
        $this->validaPrFactory->callGiamToProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['current']['NRORG'],
                'NRSEQARQMAG' => $row['current']['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileGiamTo($row);

            // Exclui os dados temporários da exportação no banco de dados
            $this->validaPrFactory->deleteGiamToData($params);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            // Exclui os dados temporários da exportaçao no banco de dados
            $this->validaPrFactory->deleteGiamToData($params);
            throw $e;
        }

    }
    
    /**
     * Função para validação dos dados informados para o GIA-To
     */
    private function validateGiamTo($row) {
        
        if (isset($row['current']['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
            
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['current']['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['current']['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['current']['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['current']['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
              // Verifica se o campo 'Livro Magnetico' possui algum vlr informado
            if(empty($row['current']['NMLIVROMAG'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Livro Magnetico deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Livro magnetico deve ser informado');
            }
            if(empty($row['dataset']['IDRETIFIC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDRETIFIC deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDTPESTAB'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDTPESTAB deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDPORTTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDPORTTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDTPESCRIT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDTPESCRIT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VRINICAIXA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VRINICAIXA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VRFIMCAIXA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VRFIMCAIXA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDUSAECF'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDUSAECF deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['CDREPRESENT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' CDREPRESENT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['NRTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' NRTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VERSAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VERSAO deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTVENCTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTVENCTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDMUDDOMICI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDMUDDOMICI deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['CDMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' CDMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTINIMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTINIMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTFINMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTFINMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTFINMUNIATU'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTFINMUNIATU deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTINIMUNIATU'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTINIMUNIATU deve ser informada.';
                $this->geraArquivo = false;
             }
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            //$nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['current']['DTREFINI']);
            $row['current']['DTINICIO'] = $datas['DTINICIO'];
            $row['current']['DTFIM']= $datas['DTFIM'];
            $row['NRORG'] = $nrorg;

        }
        else {
             // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['current']['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['current']['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['current']['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['current']['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
              // Verifica se o campo 'Livro Magnetico' possui algum vlr informado
            if(empty($row['current']['NMLIVROMAG'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Livro Magnetico deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Livro magnetico deve ser informado');
            }
            if(empty($row['dataset']['IDRETIFIC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDRETIFIC deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDTPESTAB'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDTPESTAB deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDPORTTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDPORTTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDTPESCRIT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDTPESCRIT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VRINICAIXA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VRINICAIXA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VRFIMCAIXA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VRFIMCAIXA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDUSAECF'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDUSAECF deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['CDREPRESENT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' CDREPRESENT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['NRTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' NRTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VERSAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VERSAO deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTVENCTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTVENCTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDMUDDOMICI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDMUDDOMICI deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['CDMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' CDMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTINIMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTINIMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTFINMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTFINMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTFINMUNIATU'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTFINMUNIATU deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTINIMUNIATU'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTINIMUNIATU deve ser informada.';
                $this->geraArquivo = false;
             }
        
            // var_dump($row);die;
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDaysGIAMTO($row['current']['DTREFINI']);
            $row['current']['DTINICIO'] = $datas['DTINICIO'];
            $row['current']['DTFIM']= $datas['DTFIM'];
            $row['current']['NRORG'] = $nrorg;
        
        }
    }




     /**
     * Função para a exportação DIF
     */
    public function exportardif($row) {
        // Valida os parâmetros associados.
      //  var_dump($row);die;
        $this->validateDif($row);
        
        if(isset($row['current']['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['current']['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['current']['NRORG']);
        // Monta o array com os parametros para chamar a procedure
       // var_dump($row['dataset']);die;
        $params = [
                 'CDEMPRESA' =>$row['current']['CDEMPRESA'],
                 'CDINSCESTA' =>$row['current']['CDINSCESTA'],
                 'CDCAMPO1' => $row['dataset'][0]['IDRETIFIC'],
                 'CDCAMPO2' => $row['dataset'][0]['IDTPESTAB'],
                 'CDCAMPO3' => $row['dataset'][0]['FINALIDADE'],
                 'CDCAMPO4' => $row['dataset'][0]['CDTPESCRITU'],
                 'VRCAMPO1' => $row['dataset'][0]['SALDOINICX'],
                 'VRCAMPO2' => $row['dataset'][0]['SALDOFINCX'],
                 'CDCAMPO5' => $row['dataset'][0]['VALORPATRLIQ'],
                 'CDCAMPO6' => $row['dataset'][0]['INSCESTCENT'],
                 'CDCAMPO7' => $row['dataset'][0]['REGAPUR'],
                 'CDCAMPO8' => $row['dataset'][0]['CDVERSAO'],
                 'CDCAMPO9' => $row['dataset'][0]['IDMUDAMUNI'],
                 'CDCAMPO10' => $row['dataset'][0]['CDMUNICIPIO'],
                 'DTCAMPO2' => $row['dataset'][0]['DTINIMUNIANT'],
                 'DTCAMPO3' => $row['dataset'][0]['DTFINMUNIANT'],
                  'NRSEQARQMAG' => $row['current']["NRSEQARQMAG"],
                 'LIVRO' => $row['current']["CDLIVROMAG"],
                 'DTINICIAL' => $row['current']['DTINICIAL'],
                'DTFINAL' => $row['current']['DTFINAL'],
                
        ];
            
        // Chama a procedure de exportação
        $this->validaPrFactory->callDifProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['current']['NRORG'],
                'NRSEQARQMAG' => $row['current']['NRSEQARQMAG']
            ];

            $DifData = $this->validaPrFactory->getDifData($params);
            //var_dump($row);die;
            if(empty($DifData)){
                $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
                return $fileName = false;
            }
            // Chama a função para a criação do arquivo.
            $fileName = $this->obrigacoesService->createFileExportacao($row['current']['NMARQUIVO'], $DifData, 'DSREGARQMAG');


            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
        
            throw $e;
        }

    }
    
    /**
     * Função para validação dos dados informados para o DIF
     */
    private function validateDif($row) {
        
        if (isset($row['current']['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
            
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['current']['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['current']['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['current']['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['current']['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
              // Verifica se o campo 'Livro Magnetico' possui algum vlr informado
            if(empty($row['current']['NMLIVROMAG'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Livro Magnetico deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Livro magnetico deve ser informado');
            }
            if(empty($row['dataset']['IDRETIFIC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDRETIFIC deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDTPESTAB'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDTPESTAB deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDPORTTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDPORTTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDTPESCRIT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDTPESCRIT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VRINICAIXA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VRINICAIXA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VRFIMCAIXA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VRFIMCAIXA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDUSAECF'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDUSAECF deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['CDREPRESENT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' CDREPRESENT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['NRTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' NRTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VERSAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VERSAO deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTVENCTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTVENCTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDMUDDOMICI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDMUDDOMICI deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['CDMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' CDMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTINIMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTINIMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTFINMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTFINMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTFINMUNIATU'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTFINMUNIATU deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTINIMUNIATU'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTINIMUNIATU deve ser informada.';
                $this->geraArquivo = false;
             }
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            //$nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['current']['DTREFINI']);
            $row['current']['DTINICIO'] = $datas['DTINICIO'];
            $row['current']['DTFIM']= $datas['DTFIM'];
            $row['NRORG'] = $nrorg;

        }
        else {
             // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['current']['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['current']['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['current']['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['current']['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
              // Verifica se o campo 'Livro Magnetico' possui algum vlr informado
            if(empty($row['current']['NMLIVROMAG'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Livro Magnetico deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Livro magnetico deve ser informado');
            }
            if(empty($row['dataset']['IDRETIFIC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDRETIFIC deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDTPESTAB'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDTPESTAB deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDPORTTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDPORTTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDTPESCRIT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDTPESCRIT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VRINICAIXA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VRINICAIXA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VRFIMCAIXA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VRFIMCAIXA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDUSAECF'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDUSAECF deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['CDREPRESENT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' CDREPRESENT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['NRTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' NRTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['VERSAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' VERSAO deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTVENCTARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTVENCTARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['IDMUDDOMICI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' IDMUDDOMICI deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['CDMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' CDMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTINIMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTINIMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTFINMUNIANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTFINMUNIANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTFINMUNIATU'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTFINMUNIATU deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['DTINIMUNIATU'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' DTINIMUNIATU deve ser informada.';
                $this->geraArquivo = false;
             }
        
            // var_dump($row);die;
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $row['current']['NRORG'] = $nrorg;
        
        }
    }
    
    public function saveDifTo($row) {
     //   var_dump($row['dataset']);die;
        try {
            
             $params = [
                 'CDTELA'       => 'FIS08410',
                 'CDEMPRESA'    => $row['dataset'][0]['CDEMPRESA'],
                 'CDINSCRICAO' => $row['dataset'][0]['CDINSCESTA'],
                 'CDCAMPO1' => $row['dataset'][0]['IDRETIFIC'],
                 'CDCAMPO2' => $row['dataset'][0]['IDTPESTAB'],
                 'CDCAMPO3' => $row['dataset'][0]['FINALIDADE'],
                 'CDCAMPO4' => $row['dataset'][0]['CDTPESCRITU'],
                 'VRCAMPO1' => $row['dataset'][0]['SALDOINICX'],
                 'VRCAMPO2' => $row['dataset'][0]['SALDOFINCX'],
                 'CDCAMPO5' => $row['dataset'][0]['VALORPATRLIQ'],
                 'CDCAMPO6' => $row['dataset'][0]['INSCESTCENT'],
                 'CDCAMPO7' => $row['dataset'][0]['REGAPUR'],
                 'CDCAMPO8' => $row['dataset'][0]['CDVERSAO'],
                 'CDCAMPO9' => $row['dataset'][0]['IDMUDAMUNI'],
                 'CDCAMPO10' => $row['dataset'][0]['CDMUNICIPIO'],
                 'DTCAMPO2' => $row['dataset'][0]['DTINIMUNIANT'],
                 'DTCAMPO3' => $row['dataset'][0]['DTFINMUNIANT']
             ];
           //  var_dump($params);die;
            $this->validaPrFactory->saveDifTo($params);
            
        } catch(\Exception $e) {
        
            throw $e;
        }
    }
    
    public function updateDifTo($row) {
        //var_dump($row['row']['CDEMPRESA']);die;
        try {
        
             $params = [
                 'CDEMPRESA'    => $row['row']['CDEMPRESA'],
                 'CDINSCRICAO' => $row['row']['CDINSCESTA'],
                 'CDCAMPO1' => $row['row']['IDRETIFIC'],
                 'CDCAMPO2' => $row['row']['IDTPESTAB'],
                 'CDCAMPO3' => $row['row']['FINALIDADE'],
                 'CDCAMPO4' => $row['row']['CDTPESCRITU'],
                 'VRCAMPO1' => $row['row']['SALDOINICX'],
                 'VRCAMPO2' => $row['row']['SALDOFINCX'],
                 'CDCAMPO5' => $row['row']['VALORPATRLIQ'],
                 'CDCAMPO6' => $row['row']['INSCESTCENT'],
                 'CDCAMPO7' => $row['row']['REGAPUR'],
                 'CDCAMPO8' => $row['row']['CDVERSAO'],
                 'CDCAMPO9' => $row['row']['IDMUDAMUNI'],
                 'CDCAMPO10' => $row['row']['CDMUNICIPIO'],
                 'DTCAMPO2' => $row['row']['DTINIMUNIANT'],
                 'DTCAMPO3' => $row['row']['DTFINMUNIANT']
             ];
            $this->validaPrFactory->updateDifTo($params);
            
        } catch(\Exception $e) {
        
            throw $e;
        }
    }




  //parte destinada ao DCTF
    
    private function validateDCTF($row) {
        
        if (isset($row['current']['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
            
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['current']['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['current']['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['current']['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['current']['CDINSCRICAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
            if(empty($row['dataset']['STTPDECLARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STTPDECLARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STRCBANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STRCBANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STSITUACAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STSITUACAO deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STNATJUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STNATJUR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STCDCONTADOR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STCDCONTADOR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STBLCRED'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STBLCRED deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STDBTQTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STDBTQTA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STVERSAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STVERSAO deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STTRIBLUC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STTRIBLUC deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STPESJUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPESJUR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STJAN'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STJAN deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STFEV'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STFEV deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STMAR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STMAR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STABR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STABR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STMAI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STMAI deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STJUN'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STJUN deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STJUL'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STJUL deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STAGO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STAGO deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STSET'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STSET deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STOUT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STOUT deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STNOV'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STNOV deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STDEZ'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STDEZ deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJBLC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJBLC deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJSCP'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJSCP deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJINDT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJINDT deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJSEM'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJSEM deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STCRTESCRITUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STCRTESCRITUR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STREGAPUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STREGAPUR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJMESDCLR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJMESDCLR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STDSNATJUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STDSNATJUR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STDSCONTADOR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STDSCONTADOR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJCPRB'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJCPRB deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STSITUPJ'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STSITUPJ deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STOPLEI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STOPLEI deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['PJINATIVA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' PJINATIVA deve ser informada.';
                $this->geraArquivo = false;
             }
             
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            //$nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['current']['DTREFINI']);
            $row['current']['DTINICIO'] = $datas['DTINICIO'];
            $row['current']['DTFIM']= $datas['DTFIM'];
            $row['NRORG'] = $nrorg;

        }
        else {
               // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['current']['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['current']['DTREFINI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['current']['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['current']['CDINSCRICAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
            if(empty($row['dataset']['STTPDECLARE'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STTPDECLARE deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STRCBANT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STRCBANT deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STSITUACAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STSITUACAO deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STNATJUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STNATJUR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STCDCONTADOR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STCDCONTADOR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STBLCRED'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STBLCRED deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STDBTQTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STDBTQTA deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STVERSAO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STVERSAO deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STTRIBLUC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STTRIBLUC deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STPESJUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPESJUR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STJAN'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STJAN deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STFEV'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STFEV deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STMAR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STMAR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STABR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STABR deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STMAI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STMAI deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STJUN'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STJUN deve ser informada.';
                $this->geraArquivo = false;
            }
             if(empty($row['dataset']['STJUL'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STJUL deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STAGO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STAGO deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STSET'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STSET deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STOUT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STOUT deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STNOV'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STNOV deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STDEZ'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STDEZ deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJBLC'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJBLC deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJSCP'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJSCP deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJINDT'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJINDT deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJSEM'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJSEM deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STCRTESCRITUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STCRTESCRITUR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STREGAPUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STREGAPUR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJMESDCLR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJMESDCLR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STDSNATJUR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STDSNATJUR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STDSCONTADOR'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STDSCONTADOR deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STPJCPRB'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STPJCPRB deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STSITUPJ'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STSITUPJ deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['STOPLEI'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' STOPLEI deve ser informada.';
                $this->geraArquivo = false;
             }
             if(empty($row['dataset']['PJINATIVA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.' PJINATIVA deve ser informada.';
                $this->geraArquivo = false;
             }
        
            // var_dump($row);die;
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $row['current']['NRORG'] = $nrorg;
        
        }
    }

    public function saveDCTF($row) {
        $select = [
            'CDEMPRESA' => $row['row']['CDEMPRESA']
            ];
            
          $row['row']['STNATJUR'] = $this->validaPrFactory->STNATJUR($select);
          $row['row']['STCDCONTADOR'] = $this->validaPrFactory->STCDCONTADOR($select);
          
          $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData($row['row']['DTREFINI']));
            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData($row['row']['DTREFINI']));
            $dtinicial = $dtinicial->format("d/m/Y");
            $dtfinal = $dtfinal->format("d/m/Y");
    
            $row["DTINICIAL"] = $dtinicial;
            $row["DTFINAL"] = $dtfinal;
         //   var_dump($row['row']);die;
            // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row[0]['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['row']['NRORG']);
       // var_dump($row[0]['NRSEQARQMAG']);die;
        try {
            
             $params = [
                'CDLIVROMAG' => "",
                'NRSEQARQMAG'  => $row[0]['NRSEQARQMAG'],
                'CDEMPRESA' => $row['row']['CDEMPRESA'],
                'CDCAMPO1' => $row['row']['STTPDECLARE'],
                'CDCAMPO2' => $row['row']['STRCBANT'],
                'CDCAMPO3' => $row['row']['STSITUACAO'],
                'CDCAMPO4' => $row['row']['STNATJUR'][0]['CDNATUJURI'],
                'CDCAMPO5' => $row['row']['STCDCONTADOR'][0]['CDCONTADOR2'],
                'CDCAMPO6' => $row['row']['STBLCRED'],
                'CDCAMPO7' => $row['row']['STDBTQTA'],
                'CDCAMPO8' => $row['row']['STVERSAO'],
                'CDCAMPO9' => $row['row']['STTRIBLUC'],
                'CDCAMPO10' => $row['row']['STPESJUR'], 
                'CDCAMPO11' => null,
                'CDCAMPO12' => null,
                'CDCAMPO13' => null,
                'CDCAMPO14' => null,
                'CDCAMPO15' => null,
                'CDCAMPO16' => null,
                'CDCAMPO17' => null,
                'CDCAMPO18' => null,
                'CDCAMPO19' => null,
                'CDCAMPO20' => null,
                'CDCAMPO21' => null,
                'CDCAMPO22' => null,
                'CDCAMPO23' => $row['row']['STPJBLC'],
                'CDCAMPO24' => $row['row']['STPJSCP'],
                'CDCAMPO25' => null,
                'CDCAMPO26' => null,
                'CDCAMPO27' => $row['row']['STCRTESCRITUR'],
                'CDCAMPO28' => $row['row']['STREGAPUR'],
                'CDCAMPO29' => null,
                'CDCAMPO30' => null,
                'CDCAMPO31' => null,
                'CDCAMPO32' => $row['row']['STPJCPRB'],
                'CDCAMPO33' => $row['row']['STSITUPJ'],
                'CDCAMPO34' => $row['row']['STOPLEI'],
                'CDCAMPO35' => $row['row']['PJINATIVA'],
                "DTINICIAL" => $row["DTINICIAL"],
                "DTFINAL"   => $row["DTFINAL"]
             ];
           //  var_dump($params);die;
            $this->validaPrFactory->saveDCTF($params);
            //var_dump($row['row']['STNATJUR']);die;
        } catch(\Exception $e) {
        
            throw $e;
        }
    }
    
    
    public function exportarDCTF($row) {
        // Valida os parâmetros associados.
      //  var_dump($row);die;
        $this->validateDCTF($row);
        
        if(isset($row['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['current']['NRORG']);
        // Monta o array com os parametros para chamar a procedure
       // var_dump($row['dataset']);die;
        $select = [
            'CDEMPRESA' => $row['CDEMPRESA']
            ];
            
          $row['row']['STNATJUR'] = $this->validaPrFactory->STNATJUR($select);
          $row['row']['STCDCONTADOR'] = $this->validaPrFactory->STCDCONTADOR($select);
          
       $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtinicial = $dtinicial->format("d/m/Y");
            $dtfinal = $dtfinal->format("d/m/Y");
    
            $row["DTINICIAL"] = $dtinicial;
            $row["DTFINAL"] = $dtfinal;
            
          $params = [
                'CDLIVROMAG' => "",
                'NRSEQARQMAG'  => $row['NRSEQARQMAG'],
                'CDEMPRESA' => $row['CDEMPRESA'],
                'CDCAMPO1' => $row['STTPDECLARE'],
                'CDCAMPO2' => $row['STRCBANT'],
                'CDCAMPO3' => $row['STSITUACAO'],
                'CDCAMPO4' => $row['row']['STNATJUR'][0]['CDNATUJURI'],
                'CDCAMPO5' => $row['row']['STCDCONTADOR'][0]['CDCONTADOR2'],
                'CDCAMPO6' => $row['STBLCRED'],
                'CDCAMPO7' => $row['STDBTQTA'],
                'CDCAMPO8' => $row['STVERSAO'],
                'CDCAMPO9' => $row['STTRIBLUC'],
                'CDCAMPO10' => $row['STPESJUR'], 
                'CDCAMPO11' => null,
                'CDCAMPO12' => null,
                'CDCAMPO13' => null,
                'CDCAMPO14' => null,
                'CDCAMPO15' => null,
                'CDCAMPO16' => null,
                'CDCAMPO17' => null,
                'CDCAMPO18' => null,
                'CDCAMPO19' => null,
                'CDCAMPO20' => null,
                'CDCAMPO21' => null,
                'CDCAMPO22' => null,
                'CDCAMPO23' => $row['STPJBLC'],
                'CDCAMPO24' => $row['STPJSCP'],
                'CDCAMPO25' => null,
                'CDCAMPO26' => null,
                'CDCAMPO27' => $row['STCRTESCRITUR'],
                'CDCAMPO28' => $row['STREGAPUR'],
                'CDCAMPO29' => null,
                'CDCAMPO30' => null,
                'CDCAMPO31' => null,
                'CDCAMPO32' => $row['STPJCPRB'],
                'CDCAMPO33' => $row['STSITUPJ'],
                'CDCAMPO34' => $row['STOPLEI'],
                'CDCAMPO35' => $row['PJINATIVA'],
                "DTINICIAL" => $row["DTINICIAL"],
                "DTFINAL"   => $row["DTFINAL"]
             ];
             
        // Chama a procedure de exportação
        $this->validaPrFactory->callDCTFProcedure($params);

        $fileName = $this->createFileDCTF($row); 
        return $fileName;
     

    }
    
      private function createFileDCTF($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        
        $params = [
            'NRORG' => $row['current']['NRORG'],
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];
        $DifData = $this->validaPrFactory->getDCTFData($params);
        //var_dump($row);die;
        if(isset(['current']['NRAGENDAMENTO']) && empty($DifData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $DifData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }
    
    
    
   
   
}